{
	"name":"Manufacturing industry profile",
	"version":"1.0",
	"author":"Tiny",
	"category":"Profile",
	"depends":["mrp", "crm", "sale", "delivery","board_manufacturing"],
	"demo_xml":[],
	"update_xml":[],
	"active":False,
	"installable":True,
}
